@@ -2,15 +2,14 @@
 Exceptions for uTidylib
 """
 
-__all__ = (
-    'TidyLibError', 'InvalidOptionError', 'OptionArgError',
-)
+__all__ = ("TidyLibError", "InvalidOptionError", "OptionArgError")
 
 
 class TidyLibError(Exception):
     """
     Generic Tidy exception.
     """
+
     pass
 
 
@@ -18,6 +17,7 @@ class InvalidOptionError(TidyLibError):
     """
     Exception for invalid option.
     """
+
     def __str__(self):
         return "%s was not a valid Tidy option." % (self.args[0])
 
@@ -26,4 +26,5 @@ class OptionArgError(TidyLibError):
     """
     Exception for invalid parameter.
     """
+
     pass
